from distutils.core import setup

setup(
    name = 'maxwellzhou_nester',
    version = '1.3.0',
    py_modules = ['maxwellzhou_nester'],
    author = 'Maxwell',
    author_email = 'llasionzhou@gmail.com',
    url = 'http://www.headfirstlabs.com',
    description = 'A simple printer of nested lists',
    )
